@@ -45,10 +45,6 @@ class DatabaseSchemaEditor(PostgresDatabaseSchemaEditor):
 
     def _alter_field(self, model, old_field, new_field, old_type, new_type,
                      old_db_params, new_db_params, strict=False):
-        # ALTER COLUMN TYPE is experimental.
-        # https://github.com/cockroachdb/cockroach/issues/49329
-        if self.connection.features.is_cockroachdb_20_2 and old_type != new_type:
-            self.execute('SET enable_experimental_alter_column_type_general = true')
         # Skip to the base class to avoid trying to add or drop
         # PostgreSQL-specific LIKE indexes.
         BaseDatabaseSchemaEditor._alter_field(
